<?php
/**
 * GoCardless Upgrades
 *
 * @package     Give
 * @copyright   Copyright (c) 2019, GiveWP
 * @license     https://opensource.org/licenses/gpl-license GNU Public License
 * @since       1.3.1
 */
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Upgrade script for Give-GoCardless.
 *
 * @since 1.3.1
 */
function give_gocardless_do_automatic_upgrades() {
	// Already done?
	$did_upgrade             = false;
	$give_gocardless_version = preg_replace( '/[^0-9.].*/', '', get_option( 'give_gocardless_version' ) );
	$give_gocardless_version = ! empty( $give_gocardless_version ) ? $give_gocardless_version : '1.0';

	// Update gateway label.
	if ( version_compare( $give_gocardless_version, '1.3.1', '<' ) ) {
		give_gocardless_gateway_label_callback();
		$did_upgrade = true;
	}

	// Set the version in the db.
	if ( $did_upgrade ) {
		update_option( 'give_gocardless_version', preg_replace( '/[^0-9.].*/', '', GIVE_GOCARDLESS_VERSION ) );
	}
}

// Automatic upgrade hook.
add_action( 'admin_init', 'give_gocardless_do_automatic_upgrades' );

/**
 * Copy the old GoCardless gateway label to Give 2.1.0 gateway list option.
 *
 * @since 1.3.1
 */
function give_gocardless_gateway_label_callback() {
	// Get GoCardless method label.
	$gateway_label_old = give_get_option( 'gocardless_payment_method_label' );

	if ( $gateway_label_old ) {
		// Gateway's labels.
		$give_gateway_labels = give_get_option( 'gateways_label' );

		if ( array_key_exists( 'gocardless', $give_gateway_labels ) ) {

			// Replace gateway label as per Give 2.1.0 functionality.
			$give_gateway_labels['gocardless'] = $gateway_label_old;

			// Update gateway labels.
			give_update_option( 'gateways_label', $give_gateway_labels );

			// Delete old label Permanently.
			give_delete_option( 'give_gocardless_checkout_label' );
		}
	}
}
